@@ -20,6 +20,7 @@
 
 from __future__ import division, print_function
 import sys
+import datetime
 
 import numpy as N
 from .. import qtall as qt4
@@ -33,6 +34,7 @@ defaultValues = {
     # export options
     'export_DPI': 100,
     'export_DPI_PDF': 150,
+    'export_DPI_SVG': 96,
     'export_color': True,
     'export_antialias': True,
     'export_quality': 85,
@@ -59,6 +61,9 @@ defaultValues = {
     'color_cntrlline': (True, 'blue'),
     'color_cntrlcorner': (True, 'black'),
 
+    # document theme
+    'colortheme_default': 'default-latest',
+
     # further ui options
     'toolbar_size': 24,
 
@@ -71,6 +76,10 @@ defaultValues = {
     # use document directory for export
     'dirname_export_location': 'doc',
 
+    # export templates
+    'export_template_single': '%DOCNAME%',
+    'export_template_multi': '%DOCNAME%_%PAGE00%',
+
     # ask tutorial before?
     'ask_tutorial': False,
 
@@ -80,6 +89,25 @@ defaultValues = {
 
     # add these directories to the python path (colon-separated)
     'external_pythonpath': '',
+
+    # location of ghostscript (or empty to search)
+    'external_ghostscript': '',
+
+    # translation file to load
+    'translation_file': '',
+
+    # user has disabled version update checks
+    # (packagers: please don't disable here, see disableVersionChecks in
+    #  veusz/utils/version.py)
+    'vercheck_disabled': False,
+    'vercheck_asked_user': False,
+    'vercheck_last_done': (2000,1,1),
+    'vercheck_latest': '',
+
+    # whether to send feedback about usage
+    # (packagers, please don't disable here but in veusz/setting/feedback.py)
+    'feedback_disabled': False,
+    'feedback_asked_user': False,
     }
 
 class _SettingDB(object):
@@ -155,6 +183,11 @@ class _SettingDB(object):
             if key not in self.database:
                 self.database[key] = defaultValues[key]
 
+        # keep install date for reminders, etc
+        if 'install_date' not in self.database:
+            today = datetime.date.today()
+            self.database['install_date'] = (today.year, today.month, today.day)
+
     def writeSettings(self):
         """Write the settings using QSettings.
 
@@ -200,8 +233,10 @@ class _SettingDB(object):
 settingdb = _SettingDB()
 
 # a normal dict for non-persistent settings
-# (e.g. disable safe mode)
-transient_settings = {}
+transient_settings = {
+    # disable safety checks on evaluated code
+    'unsafe_mode': False,
+}
 
 def updateUILocale():
     """Update locale to one given in preferences."""
