@@ -36,10 +36,11 @@ try:
 except ImportError:
     mmlsupport = False
 
-try:
-    from ..helpers.qtloops import RotatedRectangle
-except ImportError:
-    from .slowfuncs import RotatedRectangle
+from ..helpers.qtloops import RotatedRectangle
+
+def _(text, disambiguation=None, context='TextRender'):
+    """Translate text."""
+    return qt4.QCoreApplication.translate(context, text, disambiguation)
 
 # this definition is monkey-patched when veusz is running in self-test
 # mode as we need to hack the metrics - urgh
@@ -600,7 +601,6 @@ class RenderState(object):
                  actually_render=True):
         self.font = font
         self.painter = painter
-        self.device = painter.device()
         self.x = x     # current x position
         self.y = y     # current y position
         self.alignhorz = alignhorz
@@ -609,17 +609,11 @@ class RenderState(object):
 
     def fontMetrics(self):
         """Returns font metrics object."""
-        return FontMetrics(self.font, self.device)
+        return FontMetrics(self.font, self.painter.device())
 
     def getPixelsPerPt(self):
         """Return number of pixels per point in the rendering."""
-        painter = self.painter
-        pixperpt = painter.device().logicalDpiY() / 72.
-        try:
-            pixperpt *= painter.scaling
-        except AttributeError:
-            pass
-        return pixperpt
+        return self.painter.pixperpt
 
 class Part(object):
     """Represents a part of the text to be rendered, made up of smaller parts."""
@@ -905,7 +899,7 @@ class PartSize(Part):
             else:
                 # is an absolute font size
                 self.size = float(size)
-        except (AttributeError, ValueError):
+        except (AttributeError, ValueError, IndexError):
             self.deltasize = 0.
 
         self.children = children[1:]
@@ -951,6 +945,31 @@ class PartBar(Part):
                                      state.y-height+penw))
         painter.restore()
 
+class PartHat(Part):
+    """Draw a hat over text."""
+
+    def render(self, state):
+        initx = state.x
+
+        # draw material under bar
+        Part.render(self, state)
+
+        # draw line over text with 0.5pt thickness
+        painter = state.painter
+        height = state.fontMetrics().ascent()
+
+        painter.save()
+        penw = state.getPixelsPerPt()*0.5
+        painter.setPen( qt4.QPen(painter.pen().brush(), penw) )
+        hatheight = min((state.x-initx)/2, height / 3.)
+        painter.drawLine(
+            qt4.QPointF(initx, state.y-height+penw),
+            qt4.QPointF((initx+state.x)/2, state.y-height+penw-hatheight))
+        painter.drawLine(
+            qt4.QPointF((initx+state.x)/2, state.y-height+penw-hatheight),
+            qt4.QPointF(state.x, state.y-height+penw))
+        painter.restore()
+
 class PartDot(Part):
     """Draw a dot over text."""
 
@@ -1004,7 +1023,7 @@ class PartColor(Part):
     def __init__(self, children):
         try:
             self.colorname = children[0].text
-        except AttributeError:
+        except (AttributeError, IndexError):
             self.colorname = ''
         self.children = children[1:]
 
@@ -1013,7 +1032,7 @@ class PartColor(Part):
         pen = painter.pen()
         oldcolor = pen.color()
 
-        pen.setColor( qt4.QColor(self.colorname) )
+        pen.setColor( painter.docColor(self.colorname) )
         painter.setPen(pen)
 
         Part.render(self, state)
@@ -1037,6 +1056,7 @@ part_commands = {
     r'\frac': (PartFrac, 2),
     r'\bar': (PartBar, 1),
     r'\overline': (PartBar, 1),
+    r'\hat': (PartHat, 1),
     r'\dot': (PartDot, 1),
     r'\marker': (PartMarker, 1),
     r'\color': (PartColor, 2),
@@ -1055,6 +1075,17 @@ _                   # subscript
 )
 ''', re.VERBOSE)
 
+def latexEscape(text):
+    """Escape any special characters in LaTex-like code."""
+    # \\ is converted a unicode-special character and replaced again
+    # with the latex code later, to avoid its parts being replaced in
+    # the next step
+    text = text.replace('\\', u'\ue000')
+    # replace _, ^, {, }, [ and ] with escaped versions
+    text = re.sub(r'([_\^\[\]\{\}])', r'\\\1', text)
+    text = text.replace(u'\ue000', '{\\backslash}')
+    return text
+
 def makePartList(text):
     """Make list of parts from text"""
     parts = []
@@ -1160,9 +1191,11 @@ def makePartTree(partlist):
 class _Renderer:
     """Different renderer types based on this."""
 
-    def __init__(self, painter, font, x, y, text,
-                 alignhorz = -1, alignvert = -1, angle = 0,
-                 usefullheight = False):
+    def __init__(
+            self, painter, font, x, y, text,
+            alignhorz = -1, alignvert = -1, angle = 0,
+            usefullheight = False,
+            doc = None):
 
         self.painter = painter
         self.font = font
@@ -1170,6 +1203,7 @@ class _Renderer:
         self.alignvert = alignvert
         self.angle = angle
         self.usefullheight = usefullheight
+        self.doc = doc
 
         # x and y are the original coordinates
         # xi and yi are adjusted for alignment
@@ -1307,11 +1341,37 @@ class _Renderer:
 class _StdRenderer(_Renderer):
     """Standard rendering class."""
 
+    # expresions in brackets %{{ }}% are evaluated
+    exprexpansion = re.compile(r'%\{\{(.+?)\}\}%')
+
     def _initText(self, text):
+
+        # expand any expressions in the text
+        delta = 0
+        for m in self.exprexpansion.finditer(text):
+            expanded = self._expandExpr(m.group(1))
+            text = text[:delta+m.start()] + expanded + text[delta+m.end():]
+            delta += len(expanded) - (m.end()-m.start())
+
         # make internal tree
         partlist = makePartList(text)
         self.parttree = makePartTree(partlist)
 
+    def _expandExpr(self, expr):
+        """Expand expression."""
+        if self.doc is None:
+            return _("* Evaluation not supported here *")
+        else:
+            expr = expr.strip()
+            try:
+                comp = self.doc.evaluate.compileCheckedExpression(expr)
+                if comp is None:
+                    return _("* Evaluation error *")
+
+                return cstr(eval(comp, self.doc.evaluate.context))
+            except Exception as e:
+                return _("* Evaluation error: %s *") % latexEscape(cstr(e))
+
     def _getWidthHeight(self):
         """Get size of box around text."""
 
@@ -1321,9 +1381,11 @@ class _StdRenderer(_Renderer):
         # work out height of box, and
         # make the bounding box a bit bigger if we want to include descents
 
-        state = RenderState(self.font, self.painter, 0, 0,
-                            self.alignhorz,
-                            actually_render = False)
+        state = RenderState(
+            self.font, self.painter, 0, 0,
+            self.alignhorz,
+            actually_render = False)
+
         fm = state.fontMetrics()
 
         if self.usefullheight:
@@ -1354,9 +1416,10 @@ class _StdRenderer(_Renderer):
         if self.calcbounds is None:
             self.getBounds()
 
-        state = RenderState(self.font, self.painter,
-                            self.xi, self.yi,
-                            self.alignhorz)
+        state = RenderState(
+            self.font, self.painter,
+            self.xi, self.yi,
+            self.alignhorz)
 
         # if the text is rotated, change the coordinate frame
         if self.angle != 0:
@@ -1387,7 +1450,7 @@ class _MmlRenderer(_Renderer):
         self.size = qt4.QSize(1, 1)
         if not mmlsupport:
             self.mmldoc = None
-            self.error = 'Error: MathML support not built\n'
+            self.error = _('Error: MathML support not built\n')
             return
 
         self.mmldoc = doc = qtmml.QtMmlDocument()
@@ -1395,8 +1458,7 @@ class _MmlRenderer(_Renderer):
             self.mmldoc.setContent(text)
         except ValueError as e:
             self.mmldoc = None
-            self.error = ('Error interpreting MathML: %s\n' %
-                          cstr(e))
+            self.error = _('Error interpreting MathML: %s\n') % cstr(e)
             return
 
         # this is pretty horrible :-(
@@ -1425,13 +1487,12 @@ class _MmlRenderer(_Renderer):
         ptsize = self.font.pointSizeF()
         if ptsize < 0:
             ptsize = self.font.pixelSize() / self.painter.pixperpt
-        ptsize /= self.painter.scaling
 
         doc.setBaseFontPointSize(ptsize * upscale)
 
         # the output will be painted finally scaled
         self.drawscale = (
-            self.painter.scaling * self.painter.dpi / screendev.logicalDpiY()
+            self.painter.dpi / screendev.logicalDpiY()
             / upscale )
         self.size = doc.size() * self.drawscale
 
@@ -1472,8 +1533,10 @@ class _MmlRenderer(_Renderer):
 mml_re = re.compile(r'^\s*<math.*</math\s*>\s*$', re.DOTALL)
 
 def Renderer(painter, font, x, y, text,
-                alignhorz = -1, alignvert = -1, angle = 0,
-                usefullheight = False):
+             alignhorz = -1, alignvert = -1, angle = 0,
+             usefullheight = False,
+             doc = None):
+
     """Return an appropriate Renderer object depending on the text.
     This looks like a class name, because it was a class originally.
 
@@ -1485,6 +1548,7 @@ def Renderer(painter, font, x, y, text,
     angle is the angle to draw the text at
     usefullheight means include descenders in calculation of height
     of text
+    doc is a Document for evaluating any expressions
 
     alignment is in the painter frame, not the text frame
     """
@@ -1497,5 +1561,6 @@ def Renderer(painter, font, x, y, text,
     return r(
         painter, font, x, y, text,
         alignhorz=alignhorz, alignvert=alignvert,
-        angle=angle, usefullheight=usefullheight
+        angle=angle, usefullheight=usefullheight,
+        doc=doc
         )
