@@ -18,19 +18,19 @@
 
 '''An axis based on a function of another axis.'''
 
+from __future__ import division
 import numpy as N
 
-import veusz.qtall as qt4
-import veusz.setting as setting
-import veusz.document as document
-import veusz.utils as utils
+from ..compat import crange, cstr
+from .. import qtall as qt4
+from .. import setting
+from .. import document
 
-import axis
+from . import axis
 
 def _(text, disambiguation=None, context='FunctionAxis'):
     '''Translate text.'''
-    return unicode( 
-        qt4.QCoreApplication.translate(context, text, disambiguation))
+    return qt4.QCoreApplication.translate(context, text, disambiguation)
 
 class AxisError(RuntimeError):
     pass
@@ -71,12 +71,15 @@ def solveFunction(function, vals, mint=None, maxt=None):
         xvals = N.hstack(( xvals[xvals < maxt], maxt ))
 
     # yvalue in correct shape
-    yvals = function(xvals) + N.zeros(len(xvals))
+    try:
+        yvals = function(xvals) + N.zeros(len(xvals))
+    except Exception as e:
+        raise FunctionError(_('Error evaluating function: %s') % cstr(e))
 
     anynan = N.any( N.isnan(yvals) )
     if anynan:
-        raise FunctionError, _('Invalid regions in function '
-                               '(try setting minimum or maximum t)')
+        raise FunctionError(_('Invalid regions in function '
+                               '(try setting minimum or maximum t)'))
 
     # remove any infinite regions
     f = N.isfinite(yvals)
@@ -84,16 +87,16 @@ def solveFunction(function, vals, mint=None, maxt=None):
     yfilt = yvals[f]
 
     if len(yfilt) < 2:
-        raise FunctionError, _('Solutions to equation cannot be found')
+        raise FunctionError(_('Solutions to equation cannot be found'))
 
     # check for monotonicity
     delta = yfilt[1:] - yfilt[:-1]
     pos, neg = N.all(delta >= 0), N.all(delta <= 0)
     if not (pos or neg):
-        raise FunctionError, _('Not a monotonic function '
-                               '(try setting minimum or maximum t)')
+        raise FunctionError(_('Not a monotonic function '
+                               '(try setting minimum or maximum t)'))
     if pos and neg:
-        raise FunctionError, _('Constant function')
+        raise FunctionError(_('Constant function'))
 
     # easier if the values are increasing only
     if neg:
@@ -113,16 +116,16 @@ def solveFunction(function, vals, mint=None, maxt=None):
                 # work around value being at start of array
                 idx = 1
             else:
-                raise AxisError, _('No solution found')
+                raise AxisError(_('No solution found'))
         elif idx == len(ydelta):
-            raise AxisError, _('No solution found')
+            raise AxisError(_('No solution found'))
 
         x1, x2 = xfilt[idx-1], xfilt[idx]
         y1, y2 = ydelta[idx-1], ydelta[idx]
 
         # binary search
         tol = abs(1e-6 * thisval)
-        for i in xrange(30):
+        for i in crange(30):
             # print x1, y1, "->", x2, y2
 
             if abs(y1) <= tol and abs(y1) < abs(y2):
@@ -133,7 +136,7 @@ def solveFunction(function, vals, mint=None, maxt=None):
                 break   # found solution
 
             if y1 == y2 or ((y1<0) and (y2<0)) or ((y1>0) and (y2>0)):
-                raise AxisError, _('No solution found')
+                raise AxisError(_('No solution found'))
 
             ### This is a bit faster, but bisection is simpler
             # xv = N.linspace(x1, x2, num=100)
@@ -151,7 +154,7 @@ def solveFunction(function, vals, mint=None, maxt=None):
             x3 = 0.5*(x1+x2)
             y3 = function(x3) - thisval
             if not N.isfinite(y3):
-                raise AxisError, _('Non-finite value encountered')
+                raise AxisError(_('Non-finite value encountered'))
 
             if y3 < 0:
                 x1 = x3
@@ -173,16 +176,11 @@ class AxisFunction(axis.Axis):
     def __init__(self, *args, **argsv):
         axis.Axis.__init__(self, *args, **argsv)
 
-        self.cachedfunctxt = None
-        self.cachedcompiled = None
         self.cachedfuncobj = None
         self.cachedbounds = None
         self.funcchangeset = -1
         self.boundschangeset = -1
 
-        if type(self) == AxisFunction:
-            self.readDefaults()
-
     @classmethod
     def addSettings(klass, s):
         '''Construct list of settings.'''
@@ -222,7 +220,7 @@ class AxisFunction(axis.Axis):
         '''Write error message to document log for exception ex.'''
         self.document.log(
             _("Error in axis-function (%s): '%s'") % (
-                self.settings.function, unicode(ex)))
+                self.settings.function, cstr(ex)))
 
     def getMinMaxT(self):
         '''Get minimum and maximum t.'''
@@ -241,38 +239,21 @@ class AxisFunction(axis.Axis):
             return self.cachedfuncobj
         self.funcchangeset = self.document.changeset
 
-        functxt = self.settings.function.strip()
-        if functxt != self.cachedfunctxt:
-            self.cachedfunctxt = functxt
-            self.cachedcompiled = None
+        compiled = self.document.evaluate.compileCheckedExpression(
+            self.settings.function.strip())
 
-            # check function obeys safety rules
-            checked = utils.checkCode(functxt)
-            if checked is not None:
-                try:
-                    msg = checked[0][0]
-                except Exception, e:
-                    msg = e
-                self.logError(msg)
-            else:
-                # compile result
-                try:
-                    self.cachedcompiled = compile(functxt, '<string>', 'eval')
-                except Exception, e:
-                    self.logError(e)
-
-        if self.cachedcompiled is None:
+        if compiled is None:
             self.cachedfuncobj = None
         else:
             # a python function for doing the evaluation and handling
             # errors
-            env = self.document.eval_context.copy()
+            env = self.document.evaluate.context.copy()
 
             def function(t):
                 env['t'] = t
                 try:
-                    return eval(self.cachedcompiled, env)
-                except Exception, e:
+                    return eval(compiled, env)
+                except Exception as e:
                     self.logError(e)
                     return N.nan + t
             self.cachedfuncobj = function
@@ -280,10 +261,10 @@ class AxisFunction(axis.Axis):
             mint, maxt = self.getMinMaxT()
             try:
                 solveFunction(function, [0.], mint=mint, maxt=maxt)
-            except FunctionError, e:
+            except FunctionError as e:
                 self.logError(e)
                 self.cachedfuncobj = None
-            except AxisError, e:
+            except AxisError:
                 pass
 
         return self.cachedfuncobj
@@ -296,7 +277,7 @@ class AxisFunction(axis.Axis):
         mint, maxt = self.getMinMaxT()
         try:
             return solveFunction(fn, vals, mint=mint, maxt=maxt)
-        except Exception, e:
+        except Exception as e:
             self.logError(e)
             return None
 
@@ -339,7 +320,7 @@ class AxisFunction(axis.Axis):
             linked.computePlottedRange()
             try:
                 therange = fn(N.array(linked.plottedrange)) * N.ones(2)
-            except Exception, e:
+            except Exception as e:
                 self.logError(e)
             if not N.all( N.isfinite(therange) ):
                 therange = None
@@ -376,12 +357,16 @@ class AxisFunction(axis.Axis):
         # coordinates to translate to the other axis coordinates.
 
         # coordinate values on the other axis
-        linkwidth = link.coordParr2-link.coordParr1
-        linkorigin = link.coordParr1
-        linkpixcoords = fraccoords*linkwidth + linkorigin
-        linkbounds = link.currentbounds
+        try:
+            linkwidth = link.coordParr2-link.coordParr1
+            linkorigin = link.coordParr1
+            linkbounds = link.currentbounds
+        except AttributeError:
+            # if hasn't been initialised
+            return
 
         # lookup what pixels are on linked axis in values
+        linkpixcoords = fraccoords*linkwidth + linkorigin
         linkgraphcoords = link.plotterToGraphCoords(linkbounds, linkpixcoords)
 
         # flip round if coordinates reversed
@@ -411,7 +396,7 @@ class AxisFunction(axis.Axis):
 
         try:
             ourgraphcoords = self.getFunction()(linkgraphcoords)
-        except Exception, e:
+        except:
             return
 
         deltas = ourgraphcoords[1:] - ourgraphcoords[:-1]
@@ -470,7 +455,7 @@ class AxisFunction(axis.Axis):
 
         try:
             ourgraphcoords = self.getFunction()(tvals)
-        except Exception, e:
+        except Exception:
             return
 
         deltas = ourgraphcoords[1:] - ourgraphcoords[:-1]
@@ -523,7 +508,7 @@ class AxisFunction(axis.Axis):
 
     def _linearInterpolWarning(self, vals, xcoords, ycoords):
         '''Linear interpolation, giving out of bounds warning.'''
-        if any(vals < xcoords[0]) or any(vals > xcoords[-1]):
+        if N.any(vals < xcoords[0]) or N.any(vals > xcoords[-1]):
             self.document.log(
                 _('Warning: values exceed bounds in axis-function'))
 
