@@ -45,13 +45,6 @@ class ColorBar(axis.Axis):
     description = _('Image color bar')
     isaxis = False
 
-    def __init__(self, parent, name=None):
-        """Initialise object and create axes."""
-
-        axis.Axis.__init__(self, parent, name=name)
-        if type(self) == ColorBar:
-            self.readDefaults()
-        
     @classmethod
     def addSettings(klass, s):
         """Construct list of settings."""
@@ -197,7 +190,7 @@ class ColorBar(axis.Axis):
             minval, maxval, axisscale, cmapname, trans, invert = \
                 imgwidget.getColorbarParameters()
 
-            cmap = self.document.getColormap(cmapname, invert)
+            cmap = self.document.evaluate.getColormap(cmapname, invert)
 
             img = utils.makeColorbarImage(
                 minval, maxval, axisscale, cmap, trans,
@@ -243,7 +236,7 @@ class ColorBar(axis.Axis):
             painter.drawRect( routside )
 
         # actually draw axis
-        axis.Axis._axisDraw(self, bounds, parentposn, outerbounds, painter,
+        axis.Axis._axisDraw(self, bounds, parentposn, None, painter,
                             phelper)
 
 # allow the factory to instantiate a colorbar
