@@ -40,12 +40,6 @@ class Graph(widget.Widget):
     allowusercreation = True
     description = _('Base graph')
 
-    def __init__(self, parent, name=None):
-        """Initialise object and create axes."""
-
-        widget.Widget.__init__(self, parent, name=name)
-        self.readDefaults()
-
     @classmethod
     def addSettings(klass, s):
         """Construct list of settings."""
@@ -108,9 +102,11 @@ class Graph(widget.Widget):
 
         from . import axis
         if self.parent.getChild('x') is None:
-            axis.Axis(self, name='x')
+            ax = axis.Axis(self, name='x')
+            ax.linkToStylesheet()
         if self.parent.getChild('y') is None:
-            axis.Axis(self, name='y')
+            ay = axis.Axis(self, name='y')
+            ay.linkToStylesheet()
 
     def getAxesDict(self, axesnames, ignoremissing=False):
         """Get the axes for widgets to plot against.
@@ -250,6 +246,11 @@ class Graph(widget.Widget):
         # don't duplicate drawing axes
         axesdrawn = set()
 
+        # reset counter and compute automatic colors
+        painthelper.autoplottercount = 0
+        for c in self.children:
+            c.setupAutoColor(painter)
+
         # do normal drawing of children
         # iterate over children in reverse order
         for c in reversed(self.children):
@@ -260,9 +261,9 @@ class Graph(widget.Widget):
             axes = axesofwidget.get(c, None)
             if axes is not None and any((a in brokenaxes for a in axes)):
                 # handle broken axes
-                childbrokenaxes = sorted([ (a.name, a) for a in axes
-                                           if a in brokenaxes ])
-                childbrokenaxes.sort()
+                childbrokenaxes = sorted(
+                    [(a.name, a) for a in axes if a in brokenaxes],
+                    key=lambda x: x[0])
                 def iteratebrokenaxes(b):
                     """Recursively iterate over each broken axis and redraw
                     child for each.
@@ -280,6 +281,7 @@ class Graph(widget.Widget):
                 iteratebrokenaxes(childbrokenaxes)
 
             else:
+
                 # standard non broken axis drawing
                 c.draw(bounds, painthelper, outerbounds=outerbounds)
 
