@@ -19,6 +19,7 @@
 """For plotting shapes."""
 
 from __future__ import division, print_function
+import codecs
 import itertools
 import os
 
@@ -116,7 +117,6 @@ class BoxShape(Shape):
                          not s.get('width').isDataset(d) and
                          not s.get('height').isDataset(d) and
                          not s.get('rotate').isDataset(d) )
-        controlgraphitems = []
 
         clip = None
         if s.clip:
@@ -146,9 +146,10 @@ class BoxShape(Shape):
                 self.drawShape(painter, qt4.QRectF(-wp*0.5, -hp*0.5, wp, hp))
                 painter.restore()
 
+        controlgraphitems = []
         if x is not None and isnotdataset:
             cgi = controlgraph.ControlResizableBox(
-                self, [x, y], [wp, hp], r, allowrotate=True)
+                self, phelper, [x, y], [wp, hp], r, allowrotate=True)
             cgi.index = index
             cgi.widgetposn = posn
             index += 1
@@ -198,11 +199,6 @@ class Rectangle(BoxShape):
     description = _('Rectangle')
     allowusercreation = True
 
-    def __init__(self, parent, name=None):
-        BoxShape.__init__(self, parent, name=name)
-        if type(self) == Rectangle:
-            self.readDefaults()
-
     @classmethod
     def addSettings(klass, s):
         """Construct list of settings."""
@@ -231,11 +227,6 @@ class Ellipse(BoxShape):
     description = _('Ellipse')
     allowusercreation = True
 
-    def __init__(self, parent, name=None):
-        BoxShape.__init__(self, parent, name=name)
-        if type(self) == Ellipse:
-            self.readDefaults()
-
     def drawShape(self, painter, rect):
         s = self.settings
         path = qt4.QPainterPath()
@@ -251,8 +242,6 @@ class ImageFile(BoxShape):
 
     def __init__(self, parent, name=None):
         BoxShape.__init__(self, parent, name=name)
-        if type(self) == ImageFile:
-            self.readDefaults()
 
         self.cacheimage = None
         self.cachefilename = None
@@ -307,7 +296,7 @@ class ImageFile(BoxShape):
             return
 
         # convert to base 64 to make it nicer in the saved file
-        encoded = cbytes(qt4.QByteArray(data).toBase64()).decode('ascii')
+        encoded = codecs.encode(data, 'base64').decode('ascii')
 
         # now put embedded data in hidden setting
         ops = [
@@ -331,7 +320,7 @@ class ImageFile(BoxShape):
         self.cacheimage = qt4.QImage()
 
         # convert the embedded data from base64 and load into the image
-        decoded = qt4.QByteArray.fromBase64(s.embeddedImageData)
+        decoded = codecs.decode(s.embeddedImageData.encode('ascii'), 'base64')
         self.cacheimage.loadFromData(decoded)
 
         # we cache the data we have decoded
