@@ -42,17 +42,24 @@ class _Writer(object):
     the specified function."""
 
     def __init__(self, function):
-        """ Set the function output is sent to."""
+        """Set the function output is sent to."""
         self.function = function
 
     def write(self, text):
-        """ Send text to the output function."""
+        """Send text to the output function."""
         self.function(text)
 
     def flush(self):
-        """ Does nothing as yet."""
+        """Does nothing as yet."""
         pass
 
+class _Reader(object):
+    """Fake reading input stream object."""
+    def read(self, *args):
+        raise IOError('Interactive input not supported')
+    def readline(self, *args):
+        raise IOError('Interactive input not supported')
+
 class _CommandEdit(qt4.QLineEdit):
     """ A special class to allow entering of the command line.
 
@@ -80,7 +87,7 @@ class _CommandEdit(qt4.QLineEdit):
         self.setText("")
 
         # keep the command for history
-        self.history.append( command )
+        self.history.append(command)
         self.history_posn = len(self.history)
         self.entered_text = ''
 
@@ -141,7 +148,7 @@ class _CommandEdit(qt4.QLineEdit):
             self.setText(text)
 
 introtext=_(u'''Welcome to <b><font color="purple">Veusz %s</font></b> --- a scientific plotting application.<br>
-Copyright \u00a9 2003-2015 Jeremy Sanders &lt;jeremy@jeremysanders.net&gt; and contributors.<br>
+Copyright \u00a9 2003-2018 Jeremy Sanders &lt;jeremy@jeremysanders.net&gt; and contributors.<br>
 Veusz comes with ABSOLUTELY NO WARRANTY. Veusz is Free Software, and you are<br>
 welcome to redistribute it under certain conditions. Enter "GPL()" for details.<br>
 This window is a Python command line console and acts as a calculator.<br>
@@ -166,12 +173,14 @@ class ConsoleWindow(qt4.QDockWidget):
         # start an interpreter instance to the document
         self.interpreter = document.CommandInterpreter(thedocument)
         self.document = thedocument
-        # output from the interpreter goes to self.output_stdxxx
 
+        # streams the output/input goes to/from
         self.con_stdout = _Writer(self.output_stdout)
         self.con_stderr = _Writer(self.output_stderr)
+        self.con_stdin = _Reader()
 
-        self.interpreter.setOutputs(self.con_stdout, self.con_stderr)
+        self.interpreter.setFiles(
+            self.con_stdout, self.con_stderr, self.con_stdin)
         self.stdoutbuffer = ""
         self.stderrbuffer = ""
 
@@ -190,7 +199,7 @@ class ConsoleWindow(qt4.QDockWidget):
         hlayout = qt4.QHBoxLayout(self._hbox)
         hlayout.setContentsMargins(0,0,0,0)
         vlayout.addWidget(self._hbox)
-        
+
         self._prompt = qt4.QLabel(">>>")
         hlayout.addWidget(self._prompt)
 
@@ -209,7 +218,7 @@ class ConsoleWindow(qt4.QDockWidget):
 
     def _makeTextFormat(self, cursor, color):
         fmt = cursor.charFormat()
-        
+
         if color is not None:
             brush = qt4.QBrush(color)
             fmt.setForeground(brush)
@@ -239,26 +248,23 @@ class ConsoleWindow(qt4.QDockWidget):
         exceptions."""
 
         # preserve output streams
-        temp_stdout = sys.stdout
-        temp_stderr = sys.stderr
-        sys.stdout = _Writer(self.output_stdout)
-        sys.stderr = _Writer(self.output_stderr)
+        saved = sys.stdout, sys.stderr, sys.stdin
+        sys.stdout, sys.stderr, sys.stdin = (
+            self.con_stdout, self.con_stderr, self.con_stdin)
 
         # catch any exceptions, printing problems to stderr
-        self.document.suspendUpdates()
-        try:
-            func()
-        except:
-            # print out the backtrace to stderr
-            i = sys.exc_info()
-            backtrace = traceback.format_exception( *i )
-            for l in backtrace:
-                sys.stderr.write(l)            
-        self.document.enableUpdates()
+        with self.document.suspend():
+            try:
+                func()
+            except:
+                # print out the backtrace to stderr
+                info = sys.exc_info()
+                backtrace = traceback.format_exception(*info)
+                for line in backtrace:
+                    sys.stderr.write(line)
 
         # return output streams
-        sys.stdout = temp_stdout
-        sys.stderr = temp_stderr
+        sys.stdout, sys.stderr, sys.stdin = saved
 
     def checkVisible(self):
         """If this window is hidden, show it, then hide it again in a few
@@ -299,10 +305,10 @@ class ConsoleWindow(qt4.QDockWidget):
         # check whether command can be compiled
         # c set to None if incomplete
         try:
-            c = codeop.compile_command(newc)
+            comp = codeop.compile_command(newc)
         except Exception:
             # we want errors to be caught by self.interpreter.run below
-            c = 1
+            comp = 1
 
         # which prompt?
         prompt = '>>>'
@@ -313,19 +319,20 @@ class ConsoleWindow(qt4.QDockWidget):
         self.appendOutput('%s %s\n' % (prompt, command), 'command')
 
         # are we ready to run this?
-        if c is None or (len(command) != 0 and
-                         len(self.command_build) != 0 and
-                         (command[0] == ' ' or command[0] == '\t')):
+        if comp is None or (
+                len(command) != 0 and
+                len(self.command_build) != 0 and
+                (command[0] == ' ' or command[0] == '\t')):
             # build up the expression
             self.command_build = newc
             # modify the prompt
-            self._prompt.setText( '...' )
+            self._prompt.setText('...')
         else:
             # actually execute the command
             self.interpreter.run(newc)
             self.command_build = ''
             # modify the prompt
-            self._prompt.setText( '>>>' )
+            self._prompt.setText('>>>')
 
     def slotDocumentLog(self, text):
         """Output information if the document logs something."""
