@@ -69,8 +69,8 @@ class TutorialStep(qt4.QObject):
     def slotNextSetting(self, *args):
         """Check setting to emit next."""
         try:
-            setn = self.mainwin.document.basewidget.prefLookup(
-                self.nextonsetting[0]).get()
+            setn = self.mainwin.document.resolveSettingPath(
+                None, self.nextonsetting[0]).get()
             if self.nextonsetting[1](setn):
                 self.nextStep.emit()
         except ValueError:
@@ -448,7 +448,7 @@ class AddXYPlotter(TutorialStep):
 <p>The point plotting widget plots datasets loaded in Veusz.</p>
 
 <p class="usercmd">The flashing icon adds a point plotting (xy)
-widget. Click on this, or go to the Add menu and choose "Add xy".</p>
+widget. Click on this, or go to the Insert menu and choose "Add xy".</p>
 '''), mainwin,
             flash=mainwin.treeedit.addtoolbar.widgetForAction(
                 mainwin.vzactions['add.xy']),
@@ -528,7 +528,7 @@ class AddXY2nd(TutorialStep):
 <code>gamma</code> on the same graph.</p>
 
 <p class="usercmd">Add a second point plotting (xy) widget using the
-flashing icon, or go to the Add menu and choose "Add xy".</p>
+flashing icon, or go to the Insert menu and choose "Add xy".</p>
 '''), mainwin,
             flash=mainwin.treeedit.addtoolbar.widgetForAction(
                 mainwin.vzactions['add.xy']),
@@ -647,7 +647,7 @@ deletes it from the document.</p>
     def slotCheckDelete(self, *args):
         d = self.mainwin.document
         try:
-            d.resolve(d.basewidget, '/page1/graph1')
+            d.resolveWidgetPath(None, '/page1/graph1')
         except ValueError:
             # success!
             self.nextStep.emit()
